@@ -1,6 +1,7 @@
 from dataclasses import dataclass, field
 from typing import List, Dict
-from .hourobject import HourObject
+from .hourobjects.hourobject import HourObject
+from .hourtypelist import HourTypeList
 import logging
 
 _LOGGER = logging.getLogger(__name__)
@@ -15,28 +16,25 @@ class HoursModel:
     hours_tomorrow: HourObject = field(default_factory=lambda : HourObject([],[],dict()))
     offset_dict: Dict[Dict[str,float], Dict[str, float]] = field(default_factory=lambda: {})
 
-    def update_non_hours(
-        self, 
-        hour:int
-        ) -> None:
+    def update_all(self, hour:int) -> None:
+        self.update_non_hours(hour)
+        self.update_caution_hours(hour)
+        self.update_dynanmic_caution_hours(hour)
+        self.update_offset_dict()
+
+    def update_non_hours(self,hour:int) -> None:
         ret = []
         ret.extend(h for h in self.hours_today.nh if h >= hour)
         ret.extend(h for h in self.hours_tomorrow.nh if h < hour)
         self.non_hours = ret
     
-    def update_caution_hours(
-        self, 
-        hour:int
-        ) -> None:
+    def update_caution_hours(self, hour:int) -> None:
         ret = []
         ret.extend(h for h in self.hours_today.ch if h >= hour)
         ret.extend(h for h in self.hours_tomorrow.ch if h < hour)
         self.caution_hours = ret
 
-    def update_dynanmic_caution_hours(
-        self, 
-        hour:int
-        ) -> None:
+    def update_dynanmic_caution_hours(self, hour:int) -> None:
         ret = {}
         ret.update({k: v for k, v in self.hours_today.dyn_ch.items() if k >= hour and k not in self.hours_today.nh})
         ret.update({k: v for k, v in self.hours_tomorrow.dyn_ch.items() if k < hour and k not in self.hours_tomorrow.nh})
@@ -48,11 +46,30 @@ class HoursModel:
         ret['tomorrow'] = self.hours_tomorrow.offset_dict
         self.offset_dict = ret
 
+    def touch_midnight(self) -> bool:
+        self.hours_today = self.hours_tomorrow
+        self.hours_tomorrow = HourObject([], [], {})
+        self.offset_dict["today"] = self.offset_dict.get("tomorrow", {})
+        self.offset_dict["tomorrow"] = {}
+        return True
+
+    def update_hour_lists(self, hour:int, listtype:HourTypeList = None) -> None:
+        match listtype:
+            case HourTypeList.NonHour:
+                self.update_non_hours(hour)
+            case HourTypeList.CautionHour:
+                self.update_caution_hours(hour)
+            case HourTypeList.DynCautionHour:
+                self.update_dynanmic_caution_hours(hour)   
+            case _:
+                self.update_all(hour)
+
 @dataclass(frozen=False)
 class HourSelectionOptions:
     cautionhour_type: float = 0
     top_price: float = 0
     min_price: float = 0
+    blocknocturnal: bool = False
     absolute_top_price: float = field(init=False)
 
     def __post_init__(self):
@@ -60,9 +77,9 @@ class HourSelectionOptions:
 
     def set_absolute_top_price(self, top, min) -> None:
         if not self.validate_top_min_prices(top, min):
+            _LOGGER.warning(f"Setting top-price and min-price to zero because of min-price being larger than top-price. Please fix in options. top:{top} min:{min}")
             top = 0
             HourSelectionOptions.min_price = 0
-            _LOGGER.warning(f"Setting top-price and min-price to zero because of min-price being larger than top-price. Please fix in options. top:{top} min:{min}")
         if top is None:
             self.absolute_top_price = float("inf")
         elif top <= 0:
