@@ -12,7 +12,6 @@ class ChargerSwitch(HubMember):
             listenerentity,
             initval,
             currentname: str,
-            ampmeter_is_attribute: bool,
             hubdata=None,
             init_override:bool = False
     ):
@@ -21,8 +20,7 @@ class ChargerSwitch(HubMember):
         self._value = initval
         self._current = None
         self._current_attr_name = currentname
-        self._ampmeter_is_attribute = ampmeter_is_attribute
-        super().__init__(data_type=data_type, listenerentity=listenerentity, init_override=init_override, initval=initval)
+        super().__init__(data_type=data_type, listenerentity=listenerentity, init_override=init_override, initval=initval, hass=hass)
 
     @property
     def is_initialized(self) -> bool:
@@ -45,23 +43,23 @@ class ChargerSwitch(HubMember):
 
     def updatecurrent(self):
         if self._hubdata.chargertype.options.charger_is_outlet is True:
+            return
+        try:
+            self.current = self.get_sensor_from_hass(self._current_attr_name)
+        except:
             pass
-        elif self._ampmeter_is_attribute is True:
-            ret = self._hass.states.get(self.entity)
-            if ret is not None:
-                ret_attr = str(ret.attributes.get(self._current_attr_name))
-                self.current = ret_attr
-            else:
-                self._log_warning_once()
-        else:
-            ret = self._hass.states.get(self._current_attr_name)
-            if ret is not None:
-                self.current = ret.state
-            else:
-                self._log_warning_once()
+
+    async def async_updatecurrent(self):
+        if self._hubdata.chargertype.options.charger_is_outlet is True:
+            return
+        try:
+            self.current = await self.async_get_sensor_from_hass(self._current_attr_name)
+            return self.current
+        except:
+           await self.async_log_warning_once()
 
     HASLOGGED_INITWARN = False
-    def _log_warning_once(self):
+    async def async_log_warning_once(self):
         if not self.HASLOGGED_INITWARN:
             _LOGGER.warning("Chargerobject state was None while getting current. "
                 "Updatecurrent will still process but you may see a missmatch in frontend.")
