@@ -16,7 +16,8 @@ class PriceAwareHours(Hours):
         self._core = core_hours(
             absolute_top_price=self._set_absolute_top_price(hub.options.price.top_price),
             min_price=hub.options.price.min_price,
-            cautionhour_type=self._cautionhour_type_string
+            cautionhour_type=self._cautionhour_type_string, 
+            blocknocturnal=hub.options.blocknocturnal
         )
         self._hass = hub.state_machine
         self._prices = []
@@ -44,7 +45,7 @@ class PriceAwareHours(Hours):
 
     @property
     def absolute_top_price(self):
-        return self._core.options.absolute_top_price
+        return self._core.model.options.absolute_top_price
 
     @property
     def min_price(self):
@@ -92,6 +93,9 @@ class PriceAwareHours(Hours):
     def update_top_price(self, dyn_top_price) -> None: 
         if self._hub.options.price.dynamic_top_price:
             self._core.update_top_price(dyn_top_price)
+    
+    def update_prices(self, prices:dict = [], prices_tomorrow:dict=[]) -> None:
+        self._core.update_prices(prices, prices_tomorrow)
 
     def get_average_kwh_price(self):
         if self._is_initialized:
