@@ -4,6 +4,9 @@ from ...models.hourselection.hourselectionmodels import HourSelectionOptions
 from .schedule_session import ScheduleSession
 from ...models.chargecontroller_states import ChargeControllerStates
 
+
+
+
 class Scheduler:
     """This class obj is what constitutes a running scheduler."""
     def __init__(self, options:HourSelectionOptions = None):
@@ -103,6 +106,11 @@ class SchedulerFacade(Scheduler):
             self.create(charge_amount, departure_time, schedule_starttime, override_settings)
         self.schedule_created = True
 
+    async def async_create_schedule(self, charge_amount: float, departure_time: datetime, schedule_starttime: datetime, override_settings: bool = False):
+        if not self.scheduler_active:
+            await self.hub.state_machine.async_add_executor_job(self.create,charge_amount, departure_time, schedule_starttime, override_settings)
+        self.schedule_created = True
+
     def update(self):
         self._update(
             avg24=self._hub.sensors.powersensormovingaverage24.value,
@@ -113,14 +121,27 @@ class SchedulerFacade(Scheduler):
         )
         self.check_states()
 
+    async def async_update(self):
+        await self.hub.state_machine.async_add_executor_job(self._update, 
+                                                            self._hub.sensors.powersensormovingaverage24.value,
+                                                            self._hub.current_peak_dynamic,
+                                                            self._hub.charger.session.session_energy,
+                                                            self._hub.hours.prices,
+                                                            self._hub.hours.prices_tomorrow)
+        await self.async_check_states()
+
     def cancel(self):
         self._cancel()
         self.schedule_created = False
 
+    async def async_cancel(self):
+        await self.hub.state_machine.async_add_executor_job(self._cancel)
+        self.schedule_created = False
+
     def check_states(self):
         if not self.scheduler_active and self.schedule_created:
             self.cancel()
-        elif self._hub.chargecontroller.status is ChargeControllerStates.Done.name:
+        elif self._hub.chargecontroller.status_string is ChargeControllerStates.Done.name:
             self.cancel()
 
     @property
@@ -131,3 +152,38 @@ class SchedulerFacade(Scheduler):
     def caution_hours(self) -> dict:
         """dynamic caution hours"""
         return self.model.caution_hours
+
+
+
+
+class Schedule:
+    start_date: date
+    end_date: date
+    start_time: time
+    end_time: time
+    charge_amount: float
+    weekdays: int
+
+
+class Schedules:
+    #list of schedule with id
+    pass
+
+class SchedulerCommands:
+    def __init__(self) -> None:
+        pass
+
+    def create(self) -> int:
+        pass
+
+    def edit(self, scheduler_id: int) -> bool:
+        pass
+
+    def delete(self, scheduler_id: int) -> bool:
+        pass
+
+    def pause(self, scheduler_id: int) -> bool:
+        pass
+
+    def resume(self, scheduler_id: int) -> bool:
+        pass
\ No newline at end of file
